@@ -1,5 +1,5 @@
 /*
- * Mate system monitor colour pickers
+ * Mate system monitor color pickers
  * Copyright (C) 2007 Karl Lattimer <karl@qdh.org.uk>
  * All rights reserved.
  *
@@ -31,6 +31,7 @@
 #include <gdk/gdkkeysyms.h>
 #include <math.h>
 #include <cairo.h>
+#include <librsvg/rsvg.h>
 
 #include "gsm_color_button.h"
 
@@ -38,11 +39,11 @@
 
 struct _GSMColorButtonPrivate
 {
-    GtkWidget *cs_dialog;        /* Color selection dialog */
+    GtkWidget *cc_dialog;		/* Color chooser dialog */
 
     gchar *title;            /* Title for the color selection window */
 
-    GdkColor color;
+    GdkRGBA color;
 
     gdouble fraction;        /* Only used by GSMCP_TYPE_PIE */
     guint type;
@@ -83,13 +84,8 @@ static void gsm_color_button_get_property (GObject * object, guint param_id,
                                            GValue * value,
                                            GParamSpec * pspec);
 static void gsm_color_button_realize (GtkWidget * widget);
-#if GTK_CHECK_VERSION(3,0,0)
 static void gsm_color_button_get_preferred_width (GtkWidget * widget, gint * minimum_width, gint * natural_width);
 static void gsm_color_button_get_preferred_height (GtkWidget * widget, gint * minimum_height, gint * natural_height);
-#else
-static void gsm_color_button_size_request (GtkWidget * widget,
-                                           GtkRequisition * requisition);
-#endif
 static void gsm_color_button_size_allocate (GtkWidget * widget,
                                             GtkAllocation * allocation);
 static void gsm_color_button_unrealize (GtkWidget * widget);
@@ -180,12 +176,8 @@ gsm_color_button_class_init (GSMColorButtonClass * klass)
     gobject_class->set_property = gsm_color_button_set_property;
     gobject_class->finalize = gsm_color_button_finalize;
     widget_class->state_changed = gsm_color_button_state_changed;
-#if GTK_CHECK_VERSION(3,0,0)
     widget_class->get_preferred_width = gsm_color_button_get_preferred_width;
     widget_class->get_preferred_height = gsm_color_button_get_preferred_height;
-#else
-    widget_class->size_request = gsm_color_button_size_request;
-#endif
     widget_class->size_allocate = gsm_color_button_size_allocate;
     widget_class->realize = gsm_color_button_realize;
     widget_class->unrealize = gsm_color_button_unrealize;
@@ -219,7 +211,7 @@ gsm_color_button_class_init (GSMColorButtonClass * klass)
                                      g_param_spec_boxed ("color",
                                                          _("Current Color"),
                                                          _("The selected color"),
-                                                         GDK_TYPE_COLOR,
+                                                         GDK_TYPE_RGBA,
                                                          G_PARAM_READWRITE));
 
     g_object_class_install_property (gobject_class,
@@ -276,33 +268,35 @@ static void
 render (GtkWidget * widget)
 {
     GSMColorButton *color_button = GSM_COLOR_BUTTON (widget);
-    GdkColor *color, tmp_color = color_button->priv->color;
+    GdkRGBA *color;
+    GdkRGBA tmp_color = color_button->priv->color;
     color = &tmp_color;
     cairo_t *cr = gdk_cairo_create (gtk_widget_get_window (widget));
     cairo_path_t *path = NULL;
     gint width, height;
     gdouble radius, arc_start, arc_end;
-    gint highlight_factor;
+    gdouble highlight_factor;
 
     if (color_button->priv->highlight > 0) {
-        highlight_factor = 8192 * color_button->priv->highlight;
+        highlight_factor = 0.125 * color_button->priv->highlight;
 
-    if (color->red + highlight_factor > 65535)
-        color->red = 65535;
+    if (color->red + highlight_factor > 1.0)
+        color->red = 1.0;
     else
         color->red = color->red + highlight_factor;
 
-    if (color->blue + highlight_factor > 65535)
-        color->blue = 65535;
+    if (color->blue + highlight_factor > 1.0)
+        color->blue = 1.0;
     else
       color->blue = color->blue + highlight_factor;
 
-    if (color->green + highlight_factor > 65535)
-        color->green = 65535;
+    if (color->green + highlight_factor > 1.0)
+        color->green = 1.0;
     else
         color->green = color->green + highlight_factor;
     }
-    gdk_cairo_set_source_color (cr, color);
+    gdk_cairo_set_source_rgba (cr, color);
+
     width = gdk_window_get_width(gtk_widget_get_window(widget));
     height = gdk_window_get_height(gtk_widget_get_window(widget));
 
@@ -450,11 +444,7 @@ render (GtkWidget * widget)
 }
 
 /* Handle exposure events for the color picker's drawing area */
-#if GTK_CHECK_VERSION(3,0,0)
 static gboolean draw (GtkWidget * widget, cairo_t * cr, gpointer data)
-#else
-static gboolean expose_event (GtkWidget * widget, GdkEventExpose * event, gpointer data)
-#endif
 {
     render (GTK_WIDGET (data));
 
@@ -468,7 +458,6 @@ gsm_color_button_realize (GtkWidget * widget)
     render (widget);
 }
 
-#if GTK_CHECK_VERSION(3,0,0)
 static void gsm_color_button_get_preferred_width (GtkWidget * widget, gint * minimum_width, gint * natural_width)
 {
     g_return_if_fail (widget != NULL && minimum_width != NULL && natural_width != NULL);
@@ -485,18 +474,6 @@ static void gsm_color_button_get_preferred_height (GtkWidget * widget, gint * mi
     *minimum_height = GSMCP_MIN_HEIGHT;
     *natural_height = GSMCP_MIN_HEIGHT;
 }
-#else
-static void
-gsm_color_button_size_request (GtkWidget * widget,
-                               GtkRequisition * requisition)
-{
-    g_return_if_fail (widget != NULL || requisition != NULL);
-    g_return_if_fail (GSM_IS_COLOR_BUTTON (widget));
-
-    requisition->width = GSMCP_MIN_WIDTH;
-    requisition->height = GSMCP_MIN_HEIGHT;
-}
-#endif
 
 static void
 gsm_color_button_size_allocate (GtkWidget * widget,
@@ -581,15 +558,16 @@ gsm_color_button_drag_data_received (GtkWidget * widget,
 
 
 static void
-set_color_icon (GdkDragContext * context, GdkColor * color)
+set_color_icon (GdkDragContext * context, GdkRGBA * color)
 {
     GdkPixbuf *pixbuf;
     guint32 pixel;
 
     pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 48, 32);
 
-    pixel = ((color->red & 0xff00) << 16) |
-          ((color->green & 0xff00) << 8) | (color->blue & 0xff00);
+    pixel = ((guint32)(color->red * 0xff) << 24) |
+            ((guint32)(color->green * 0xff) << 16) |
+            ((guint32)(color->blue * 0xff) << 8);
 
     gdk_pixbuf_fill (pixbuf, pixel);
 
@@ -661,11 +639,7 @@ gsm_color_button_init (GSMColorButton * color_button)
 
     gtk_widget_set_tooltip_text (GTK_WIDGET(color_button), _("Click to set graph colors"));
 
-#if GTK_CHECK_VERSION(3,0,0)
     g_signal_connect (color_button, "draw", G_CALLBACK (draw), color_button);
-#else
-    g_signal_connect (color_button, "expose-event", G_CALLBACK (expose_event), color_button);
-#endif
 }
 
 static void
@@ -673,9 +647,9 @@ gsm_color_button_finalize (GObject * object)
 {
     GSMColorButton *color_button = GSM_COLOR_BUTTON (object);
 
-    if (color_button->priv->cs_dialog != NULL)
-        gtk_widget_destroy (color_button->priv->cs_dialog);
-    color_button->priv->cs_dialog = NULL;
+    if (color_button->priv->cc_dialog != NULL)
+        gtk_widget_destroy (color_button->priv->cc_dialog);
+    color_button->priv->cc_dialog = NULL;
 
     g_free (color_button->priv->title);
     color_button->priv->title = NULL;
@@ -687,7 +661,7 @@ gsm_color_button_finalize (GObject * object)
 }
 
 GtkWidget *
-gsm_color_button_new (const GdkColor * color, guint type)
+gsm_color_button_new (const GdkRGBA * color, guint type)
 {
     return g_object_new (GSM_TYPE_COLOR_BUTTON, "color", color, "type", type,
                          NULL);
@@ -697,17 +671,14 @@ static void
 dialog_response (GtkWidget * widget, GtkResponseType response, gpointer data)
 {
     GSMColorButton *color_button = GSM_COLOR_BUTTON (data);
-    GtkColorSelection *color_selection;
+    GtkColorChooser *color_chooser;
 
     if (response == GTK_RESPONSE_OK) {
-        color_selection =
-            GTK_COLOR_SELECTION (gtk_color_selection_dialog_get_color_selection (GTK_COLOR_SELECTION_DIALOG
-                                 (color_button->priv->cs_dialog)));
+        color_chooser = GTK_COLOR_CHOOSER (color_button->priv->cc_dialog);
 
-        gtk_color_selection_get_current_color (color_selection,
-                                               &color_button->priv->color);
+        gtk_color_chooser_get_rgba (color_chooser, &color_button->priv->color);
 
-        gtk_widget_hide (color_button->priv->cs_dialog);
+        gtk_widget_hide (color_button->priv->cc_dialog);
 
         gtk_widget_queue_draw (GTK_WIDGET (&color_button->widget));
 
@@ -718,7 +689,7 @@ dialog_response (GtkWidget * widget, GtkResponseType response, gpointer data)
         g_object_thaw_notify (G_OBJECT (color_button));
     }
     else  /* (response == GTK_RESPONSE_CANCEL) */
-        gtk_widget_hide (color_button->priv->cs_dialog);
+        gtk_widget_hide (color_button->priv->cc_dialog);
 }
 
 static gboolean
@@ -726,7 +697,7 @@ dialog_destroy (GtkWidget * widget, gpointer data)
 {
     GSMColorButton *color_button = GSM_COLOR_BUTTON (data);
 
-    color_button->priv->cs_dialog = NULL;
+    color_button->priv->cc_dialog = NULL;
 
     return FALSE;
 }
@@ -735,51 +706,36 @@ static gint
 gsm_color_button_clicked (GtkWidget * widget, GdkEventButton * event)
 {
     GSMColorButton *color_button = GSM_COLOR_BUTTON (widget);
-    GtkColorSelectionDialog *color_dialog;
 
     /* if dialog already exists, make sure it's shown and raised */
-    if (!color_button->priv->cs_dialog)
+    if (!color_button->priv->cc_dialog)
     {
         /* Create the dialog and connects its buttons */
+        GtkWidget *cc_dialog;
         GtkWidget *parent;
 
         parent = gtk_widget_get_toplevel (GTK_WIDGET (color_button));
+        if (!gtk_widget_is_toplevel (parent))
+            parent = NULL;
 
-        color_button->priv->cs_dialog =
-            gtk_color_selection_dialog_new (color_button->priv->title);
+        cc_dialog = gtk_color_chooser_dialog_new (color_button->priv->title, GTK_WINDOW (parent));
 
-        color_dialog =
-            GTK_COLOR_SELECTION_DIALOG (color_button->priv->cs_dialog);
+        gtk_window_set_modal (GTK_WINDOW (cc_dialog), TRUE);
 
-        if (gtk_widget_is_toplevel (parent) && GTK_IS_WINDOW (parent))
-        {
-            if (GTK_WINDOW (parent) !=
-                gtk_window_get_transient_for (GTK_WINDOW (color_dialog)))
-            gtk_window_set_transient_for (GTK_WINDOW (color_dialog),
-                                          GTK_WINDOW (parent));
-
-        gtk_window_set_modal (GTK_WINDOW (color_dialog),
-                              gtk_window_get_modal (GTK_WINDOW (parent)));
-        }
-
-        g_signal_connect (color_dialog, "response",
+        g_signal_connect (cc_dialog, "response",
                           G_CALLBACK (dialog_response), color_button);
 
-        g_signal_connect (color_dialog, "destroy",
+        g_signal_connect (cc_dialog, "destroy",
                           G_CALLBACK (dialog_destroy), color_button);
+
+        color_button->priv->cc_dialog = cc_dialog;
     }
 
-    color_dialog = GTK_COLOR_SELECTION_DIALOG (color_button->priv->cs_dialog);
+    gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (color_button->priv->cc_dialog),
+                                &color_button->priv->color);
 
-    gtk_color_selection_set_previous_color (GTK_COLOR_SELECTION
-                                            (gtk_color_selection_dialog_get_color_selection (color_dialog)),
-                                            &color_button->priv->color);
+    gtk_window_present (GTK_WINDOW (color_button->priv->cc_dialog));
 
-    gtk_color_selection_set_current_color (GTK_COLOR_SELECTION
-                                           (gtk_color_selection_dialog_get_color_selection (color_dialog)),
-                                            &color_button->priv->color);
-
-    gtk_window_present (GTK_WINDOW (color_button->priv->cs_dialog));
     return 0;
 }
 
@@ -867,18 +823,19 @@ gsm_color_button_set_fraction (GSMColorButton * color_button,
 }
 
 void
-gsm_color_button_get_color (GSMColorButton * color_button, GdkColor * color)
+gsm_color_button_get_color (GSMColorButton * color_button, GdkRGBA * color)
 {
     g_return_if_fail (GSM_IS_COLOR_BUTTON (color_button));
 
     color->red = color_button->priv->color.red;
     color->green = color_button->priv->color.green;
     color->blue = color_button->priv->color.blue;
+    color->alpha = color_button->priv->color.alpha;
 }
 
 void
 gsm_color_button_set_color (GSMColorButton * color_button,
-                            const GdkColor * color)
+                            const GdkRGBA * color)
 {
     g_return_if_fail (GSM_IS_COLOR_BUTTON (color_button));
     g_return_if_fail (color != NULL);
@@ -886,6 +843,7 @@ gsm_color_button_set_color (GSMColorButton * color_button,
     color_button->priv->color.red = color->red;
     color_button->priv->color.green = color->green;
     color_button->priv->color.blue = color->blue;
+    color_button->priv->color.alpha = color->alpha;
 
     gtk_widget_queue_draw (GTK_WIDGET (&color_button->widget));    //->priv->draw_area);
 
@@ -904,8 +862,8 @@ gsm_color_button_set_title (GSMColorButton * color_button,
     color_button->priv->title = g_strdup (title);
     g_free (old_title);
 
-    if (color_button->priv->cs_dialog)
-        gtk_window_set_title (GTK_WINDOW (color_button->priv->cs_dialog),
+    if (color_button->priv->cc_dialog)
+        gtk_window_set_title (GTK_WINDOW (color_button->priv->cc_dialog),
                               color_button->priv->title);
 
     g_object_notify (G_OBJECT (color_button), "title");
@@ -952,7 +910,7 @@ gsm_color_button_get_property (GObject * object,
                                GValue * value, GParamSpec * pspec)
 {
     GSMColorButton *color_button = GSM_COLOR_BUTTON (object);
-    GdkColor color;
+    GdkRGBA color;
 
     switch (param_id)
     {
