@@ -61,40 +61,6 @@ namespace
     };
 
 
-
-
-#if 0
-
-    struct ColumnState
-    {
-        unsigned visible;
-        unsigned id;
-        unsigned width;
-
-        int pack() const
-        {
-            unsigned p = 0;
-            p |= (this->visible & 0x0001) << 24;
-            p |= (this->id      & 0x00ff) << 16;
-            p |= (this->width   & 0xffff);
-            return p;
-        }
-
-        void unpack(int i)
-        {
-            this->visible = 0x0001 & (i >> 24);
-            this->id      = 0x00ff & (i >> 16);
-            this->width   = 0xffff & i;
-        }
-    };
-
-
-
-
-#endif
-
-
-
     class InodeDevices
     {
         typedef std::map<guint16, string> Map;
@@ -378,7 +344,6 @@ create_memmapsdata (ProcData *procdata)
                                 );
 
     tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (tree), TRUE);
     g_object_unref (G_OBJECT (model));
 
     for (i = 0; i < MMAP_COL_MAX; i++) {
