@@ -261,7 +261,6 @@ create_openfiles_tree (ProcData *procdata)
         );
 
     tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
-    gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (tree), TRUE);
     g_object_unref (G_OBJECT (model));
 
     for (i = 0; i < NUM_OPENFILES_COL-1; i++) {
@@ -282,22 +281,9 @@ create_openfiles_tree (ProcData *procdata)
         gtk_tree_view_append_column (GTK_TREE_VIEW (tree), column);
     }
 
-#if 0
-    gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
-                                     COL_VMSZ,
-                                     sort_ints,
-                                     GINT_TO_POINTER (COL_FD),
-                                     NULL);
-/*gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
-  0,
-  GTK_SORT_ASCENDING);*/
-#endif
-
     procman_get_tree_state (procdata->settings, tree, procman::settings::open_files_tree_prefix.c_str());
 
-
     return tree;
-
 }
 
 
@@ -347,11 +333,11 @@ create_single_openfiles_dialog (GtkTreeModel *model, GtkTreePath *path,
     gtk_box_set_spacing (GTK_BOX (vbox), 2);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 
-    dialog_vbox = gtk_vbox_new (FALSE, 6);
+    dialog_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_container_set_border_width (GTK_CONTAINER (dialog_vbox), 5);
     gtk_box_pack_start (GTK_BOX (vbox), dialog_vbox, TRUE, TRUE, 0);
 
-    cmd_hbox = gtk_hbox_new (FALSE, 12);
+    cmd_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
     gtk_box_pack_start (GTK_BOX (dialog_vbox), cmd_hbox, FALSE, FALSE, 0);
 
 
