@@ -413,11 +413,7 @@ create_field_page(GtkWidget *tree, const gchar *child_schema, const gchar *text)
     vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
 
     label = gtk_label_new_with_mnemonic (text);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
     gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
 
     scrolled = gtk_scrolled_window_new (NULL, NULL);
@@ -564,11 +560,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
     tmp = g_strdup_printf ("<b>%s</b>", _("Behavior"));
     label = gtk_label_new (NULL);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
     gtk_label_set_markup (GTK_LABEL (label), tmp);
     g_free (tmp);
     gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
@@ -586,11 +578,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
     gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 
     label = gtk_label_new_with_mnemonic (_("_Update interval in seconds:"));
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
     gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
 
     hbox3 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
@@ -660,11 +648,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
     tmp = g_strdup_printf ("<b>%s</b>", _("Information Fields"));
     label = gtk_label_new (NULL);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
     gtk_label_set_markup (GTK_LABEL (label), tmp);
     g_free (tmp);
     gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
@@ -689,11 +673,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
     tmp = g_strdup_printf ("<b>%s</b>", _("Graphs"));
     label = gtk_label_new (NULL);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
     gtk_label_set_markup (GTK_LABEL (label), tmp);
     g_free (tmp);
     gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, FALSE, 0);
@@ -711,11 +691,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
     gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 
     label = gtk_label_new_with_mnemonic (_("_Update interval in seconds:"));
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
     gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
     gtk_size_group_add_widget (size, label);
 
@@ -759,11 +735,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
     tmp = g_strdup_printf ("<b>%s</b>", _("File Systems"));
     label = gtk_label_new (NULL);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
     gtk_label_set_markup (GTK_LABEL (label), tmp);
     g_free (tmp);
     gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
@@ -781,11 +753,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
     gtk_box_pack_start (GTK_BOX (vbox2), hbox2, FALSE, FALSE, 0);
 
     label = gtk_label_new_with_mnemonic (_("_Update interval in seconds:"));
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
     gtk_box_pack_start (GTK_BOX (hbox2), label, FALSE, FALSE, 0);
 
     hbox3 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
@@ -820,11 +788,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
     tmp = g_strdup_printf ("<b>%s</b>", _("Information Fields"));
     label = gtk_label_new (NULL);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
     gtk_label_set_markup (GTK_LABEL (label), tmp);
     g_free (tmp);
     gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
