@@ -125,11 +125,7 @@ procman_make_label_for_mmaps_or_ofiles(const char *format,
     name = mnemonic_safe_process_name (process_name);
     title = g_strdup_printf(format, name, pid);
     label = gtk_label_new_with_mnemonic (title);
-#if GTK_CHECK_VERSION (3, 16, 0)
     gtk_label_set_xalign (GTK_LABEL (label), 0.0);
-#else
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-#endif
 
     g_free (title);
     g_free (name);
