@@ -5,29 +5,10 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <stddef.h>
-#include <cstring>
 #include <string>
-#include <functional>
-#include <algorithm>
 
 using std::string;
 
-template<typename T>
-inline int procman_cmp(T x, T y)
-{
-    if (x == y)
-        return 0;
-
-    if (x < y)
-        return -1;
-
-    return 1;
-}
-
-#define PROCMAN_CMP(X, Y) procman_cmp((X), (Y))
-#define PROCMAN_RCMP(X, Y) procman_cmp((Y), (X));
-
 /* check if logind is running */
 #define LOGIND_RUNNING() (access("/run/systemd/seats/", F_OK) >= 0)
 
@@ -61,30 +42,10 @@ inline string make_string(char *c_str)
 }
 
 
-
-
-template<typename Map>
-class UnrefMapValues
-    : public std::unary_function<void, Map>
-{
-public:
-    void operator()(const typename Map::value_type &it) const
-    {
-        if (it.second)
-            g_object_unref(it.second);
-    }
-};
-
-
-template<typename Map>
-inline void unref_map_values(Map &map)
-{
-    std::for_each(map.begin(), map.end(), UnrefMapValues<Map>());
-}
-
-
 namespace procman
 {
+    gchar* format_duration_for_display(unsigned centiseconds);
+
     void size_cell_data_func(GtkTreeViewColumn *col, GtkCellRenderer *renderer,
                              GtkTreeModel *model, GtkTreeIter *iter,
                              gpointer user_data);
